﻿using CarpentryWorkshop.Entities;
using CarpentryWorkshop.Repositories;

namespace CarpentryWorkshop.Forms
{
    public partial class FormMaterial : Form
    {
        private readonly IMaterialRepository _materialRepository;
        private int? _materialId;
        public int Id
        {
            set
            {
                try
                {
                    var material = _materialRepository.ReadMaterialById(value);
                    if (material == null)
                    {
                        throw new InvalidDataException(nameof(material));
                    }
                    textBoxName.Text = material.Name;
                    numericUpDownCount.Value = material.Count;
                    numericUpDownReversedCount.Value = material.ReservInWarehouse;
                    _materialId = value;
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }
        }
        public FormMaterial(IMaterialRepository materialRepository)
        {
            InitializeComponent();
            _materialRepository = materialRepository ?? throw new ArgumentNullException(nameof(materialRepository));
        }
        private void ButtonAdd_Click(object sender, EventArgs e)
        {
            try
            {
                if (string.IsNullOrWhiteSpace(textBoxName.Text))
                {
                    throw new Exception("Имеются незаполненные поля");
                }
                if (numericUpDownCount.Value < numericUpDownReversedCount.Value)
                {
                    throw new Exception("Нельзя зарезервировать больше чем храниться на складе");
                }
                if (_materialId.HasValue)
                {
                    _materialRepository.UpdateMaterial(CreateMaterial(_materialId.Value));
                }
                else
                {
                    _materialRepository.CreateMaterial(CreateMaterial(0));
                }
                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private void ButtonCancel_Click(object sender, EventArgs e) => Close();
        private Material CreateMaterial(int id) => Material.CreateEntity(id, textBoxName.Text, Convert.ToInt32(numericUpDownCount.Value), Convert.ToInt32(numericUpDownReversedCount.Value));  
    }
}
