﻿using CarpentryWorkshop.Entities;
using CarpentryWorkshop.Repositories;

namespace CarpentryWorkshop.Forms
{
    public partial class FormMaterialReplenishment : Form
    {
        private readonly IMaterialReplenishmentRepository _materialSpentRepository;
        private int? _materialSpentId;
        public int Id
        {
            set
            {
                try
                {
                    var materialSpent = _materialSpentRepository.ReadMaterialSpentById(value);
                    if (materialSpent == null)
                    {
                        throw new InvalidDataException(nameof(materialSpent));
                    }
                    textBoxName.Text = materialSpent.Name;
                    numericUpDownCount.Value = materialSpent.Count;
                    _materialSpentId = value;
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }
        }
        public FormMaterialReplenishment(IMaterialReplenishmentRepository materialSpentRepository)
        {
            InitializeComponent();
            _materialSpentRepository = materialSpentRepository ?? throw new ArgumentNullException(nameof(materialSpentRepository));
        }
        private MaterialReplenishment CreateMaterialSpent(int id) => MaterialReplenishment.CreateOperation(id, textBoxName.Text, Convert.ToInt32(numericUpDownCount.Value));
        private void buttonAdd_Click_1(object sender, EventArgs e)
        {
            try
            {
                if (string.IsNullOrWhiteSpace(textBoxName.Text))
                {
                    throw new Exception("Имеются незаполненные поля");
                }

                if (_materialSpentId.HasValue)
                {
                    _materialSpentRepository.UpdateMaterialSpent(CreateMaterialSpent(_materialSpentId.Value));
                }
                else
                {
                    _materialSpentRepository.CreateMaterialSpent(CreateMaterialSpent(0));
                }
                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private void buttonCancel_Click_1(object sender, EventArgs e) => Close();
    }
}
