﻿using CarpentryWorkshop.Entities;
using CarpentryWorkshop.Entities.Enums;
using CarpentryWorkshop.Repositories;

namespace CarpentryWorkshop.Forms
{
    public partial class FormOrderProduct : Form
    {
        private readonly IOrderRepository _orderRepository;
        public FormOrderProduct(IOrderRepository orderRepository, IProductRepository productRepository)
        {
            InitializeComponent();
            _orderRepository = orderRepository ?? throw new ArgumentNullException(nameof(orderRepository));

            comboBoxStatus.DataSource = Enum.GetValues(typeof(OrderStatus));

            ColumnProducts.DataSource = productRepository.ReadProducts();
            ColumnProducts.DisplayMember = "Name";
            ColumnProducts.ValueMember = "Id";
        }
        private void ButtonAdd_Click(object sender, EventArgs e)
        {
            if (dataGridView.RowCount < 1 || textBoxDescription.Text == null || comboBoxStatus.SelectedIndex < 0)
            {
                throw new Exception("Имеются незаполненны поля");
            }
            try
            {
                _orderRepository.CreateOrder(Order.CreateOperation(0, (OrderStatus)comboBoxStatus.SelectedValue!, textBoxDescription.Text, CreateListProductFromDataGrid()));
                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private void ButtonCancel_Click(object sender, EventArgs e) => Close();
        private List<OrderProduct> CreateListProductFromDataGrid()
        {
            var list = new List<OrderProduct>();
            foreach (DataGridViewRow row in dataGridView.Rows)
            {
                if (row.Cells["ColumnProducts"].Value == null || row.Cells["ColumnCount"].Value == null)
                {
                    continue;
                }
                list.Add(OrderProduct.CreateOperation(0, Convert.ToInt32(row.Cells["ColumnProducts"].Value), Convert.ToInt32(row.Cells["ColumnCount"].Value)));
            }
            return list;
        }
    }
}
